@@ -8,7 +8,7 @@ use WebAPI::DBIC::WebApp;
 use WebAPI::DBIC::RouteMaker;
 use Mojolicious::Plugin::WebAPI::Proxy;
  
-our $VERSION = '0.02';
+our $VERSION = '0.03';
  
 sub register {
     my ($self, $app, $conf) = @_;
@@ -25,7 +25,7 @@ sub register {
 
     my $psgi_app = WebAPI::DBIC::WebApp->new({
         %opts,
-        schema => $schema,
+        routes => [ map { $schema->source($_) } $schema->sources ],
     })->to_psgi_app;
 
     $route->detour(
@@ -50,7 +50,7 @@ Mojolicious::Plugin::WebAPI - Mojolicious::Plugin::WebAPI - mount WebAPI::DBIC i
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
